@@ -1,5 +1,5 @@
 # sql/operators.py
-# Copyright (C) 2005-2016 the SQLAlchemy authors and contributors
+# Copyright (C) 2005-2017 the SQLAlchemy authors and contributors
 # <see AUTHORS file>
 #
 # This module is part of SQLAlchemy and is released under
@@ -159,7 +159,7 @@ class Operators(object):
         return against
 
     def operate(self, op, *other, **kwargs):
-        """Operate on an argument.
+        r"""Operate on an argument.
 
         This is the lowest level of operation, raises
         :class:`NotImplementedError` by default.
@@ -398,13 +398,16 @@ class ColumnOperators(Operators):
         return self.operate(concat_op, other)
 
     def like(self, other, escape=None):
-        """Implement the ``like`` operator.
+        r"""Implement the ``like`` operator.
 
-        In a column context, produces the clause ``a LIKE other``.
+        In a column context, produces the expression::
+
+            a LIKE other
 
         E.g.::
 
-            select([sometable]).where(sometable.c.column.like("%foobar%"))
+            stmt = select([sometable]).\
+                where(sometable.c.column.like("%foobar%"))
 
         :param other: expression to be compared
         :param escape: optional escape character, renders the ``ESCAPE``
@@ -420,13 +423,20 @@ class ColumnOperators(Operators):
         return self.operate(like_op, other, escape=escape)
 
     def ilike(self, other, escape=None):
-        """Implement the ``ilike`` operator.
+        r"""Implement the ``ilike`` operator, e.g. case insensitive LIKE.
 
-        In a column context, produces the clause ``a ILIKE other``.
+        In a column context, produces an expression either of the form::
+
+            lower(a) LIKE lower(other)
+
+        Or on backends that support the ILIKE operator::
+
+            a ILIKE other
 
         E.g.::
 
-            select([sometable]).where(sometable.c.column.ilike("%foobar%"))
+            stmt = select([sometable]).\
+                where(sometable.c.column.ilike("%foobar%"))
 
         :param other: expression to be compared
         :param escape: optional escape character, renders the ``ESCAPE``
@@ -651,6 +661,22 @@ class ColumnOperators(Operators):
         """Produce a :func:`~.expression.any_` clause against the
         parent object.
 
+        This operator is only appropriate against a scalar subquery
+        object, or for some backends an column expression that is
+        against the ARRAY type, e.g.::
+
+            # postgresql '5 = ANY (somearray)'
+            expr = 5 == mytable.c.somearray.any_()
+
+            # mysql '5 = ANY (SELECT value FROM table)'
+            expr = 5 == select([table.c.value]).as_scalar().any_()
+
+        .. seealso::
+
+            :func:`~.expression.any_` - standalone version
+
+            :func:`~.expression.all_` - ALL operator
+
         .. versionadded:: 1.1
 
         """
@@ -660,6 +686,22 @@ class ColumnOperators(Operators):
         """Produce a :func:`~.expression.all_` clause against the
         parent object.
 
+        This operator is only appropriate against a scalar subquery
+        object, or for some backends an column expression that is
+        against the ARRAY type, e.g.::
+
+            # postgresql '5 = ALL (somearray)'
+            expr = 5 == mytable.c.somearray.all_()
+
+            # mysql '5 = ALL (SELECT value FROM table)'
+            expr = 5 == select([table.c.value]).as_scalar().all_()
+
+        .. seealso::
+
+            :func:`~.expression.all_` - standalone version
+
+            :func:`~.expression.any_` - ANY operator
+
         .. versionadded:: 1.1
 
         """
